@@ -9,8 +9,14 @@ class Regime:
         self.size = size
         if k == None or (k <= (size - 2) and k >= (-size + 2)):
             self.k = k
+            self.is_out_of_range = False
         else:
-            raise Exception("k is out of bound")
+            self.is_out_of_range = True
+            # raise Exception("k = {} is out of bound".format(k))
+            if k >= 0:
+                self.k = size - 2
+            else:
+                self.k = -(size - 2)
 
     @property
     def reg_s(self):
@@ -34,17 +40,6 @@ class Regime:
             return -self.k + 1  # not bound checked
             # return min(self.size - 1, -self.k + 1) # bound checked
 
-    # @property
-    # def _reg_len_bound_checked(self):
-    #     """regime length, used to represent the regime. It accounts for edge cases.
-    #     e.g.:
-    #     (reg_s, reg_len) = (1, 8) -> k = 6
-    #     regime: 0_1111111
-    #     """
-    #     if self.k == None:  # 0 or inf
-    #         return None
-    #     return min(self.size - 1, self.reg_len)  # bound checked
-
     def calc_reg_bits(self):
         if self.k == None:
             return 0
@@ -62,7 +57,7 @@ class Regime:
                 # >>> Regime(size=8, k=-7)
                 # (reg_s, reg_len) = (0, 8) -> k = -7
                 # regime: 00000000
-                return 0
+                raise Exception("regime bit fields all zeros is unexpected. the posit is a 'special' representation.")
 
     def __eq__(self, other):
         if isinstance(other, self.__class__):
